@@ -181,9 +181,9 @@ class LDAPModel():
         """
             Save this entry and its attributes to the LDAP server.
         """
-        for name, attr in {n: a for n, a in self._attrs.items() if 'server_default' is not None}.items():
+        for name, attr in {n: a for n, a in self._attrs.items() if attr.server_default is not None}.items():
             if not getattr(self, name) and getattr(self, name) is not False:
-                setattr(self, name, attr['server_default'])
+                setattr(self, name, attr.server_default)
         return self._entry.save()
 
     def delete(self):
